from mastercardapicore import *

# import apis resourceconfig
from mastercardspendalerts.resourceconfig import ResourceConfig


# import apis into api package
from mastercardspendalerts.alerts import *
from mastercardspendalerts.amount import *
from mastercardspendalerts.card import *
from mastercardspendalerts.carddisable import *
from mastercardspendalerts.channel import *
from mastercardspendalerts.controls import *
from mastercardspendalerts.crossborder import *
from mastercardspendalerts.declines import *
from mastercardspendalerts.verify import *
